@@ -1,7 +1,8 @@
 from argparse import RawTextHelpFormatter
 from fa import utils
 
-DESCRIPTION = '''unite with another command's resultset
+DESCRIPTION = '''[DEPRECATED]
+unite with another command's resultset
 
 EXAMPLE:
     results = [80]
@@ -23,6 +24,7 @@ def get_parser():
     return p
 
 
+@utils.deprecated
 def or_(addresses, cmd, interpreter):
     results = set(addresses)
     results.update(
